
# ToDos

* Add ability to retrieve advanced transcript data
* Raise helpful error if the user tries to make a call that the current plan doesn't support


# Considerations

* Consider implementing @dataclass and @dataclass_json from scratch to avoid third-party dependency
